# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import bbcode.models
import django.core.validators


class Migration(migrations.Migration):

    replaces = [("frappe", "0001_initial"), ("frappe", "0002_nouveau_bbcode")]

    dependencies = [
        ("portailuser", "0002_auto_20150620_2339"),
        ("attachments", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Annee",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("nom", models.CharField(max_length=16)),
                (
                    "ecole",
                    models.ForeignKey(
                        editable=False,
                        to="portailuser.Ecole",
                        verbose_name="\xc9cole",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Commentaire",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "derniere_modif",
                    models.DateTimeField(auto_now=True, auto_now_add=True),
                ),
                ("creation", models.DateTimeField(auto_now_add=True)),
                ("message", bbcode.models.BBCodeField(pack=b"message")),
                (
                    "auteur",
                    models.ForeignKey(
                        to="portailuser.PortailUser", on_delete=models.CASCADE
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Document",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("nom", models.CharField(max_length=64)),
                (
                    "annee",
                    models.PositiveSmallIntegerField(
                        null=True, verbose_name="Ann\xe9e", blank=True
                    ),
                ),
                (
                    "description",
                    bbcode.models.BBCodeField(null=True, pack=b"message", blank=True),
                ),
                (
                    "derniere_modif",
                    models.DateTimeField(auto_now=True, auto_now_add=True),
                ),
                ("creation", models.DateTimeField(auto_now_add=True)),
                (
                    "auteur",
                    models.ForeignKey(
                        to="portailuser.PortailUser", on_delete=models.CASCADE
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="DocumentFichier",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("fichier", models.FileField(upload_to=b"frappe")),
                ("ordre", models.PositiveSmallIntegerField()),
                (
                    "document",
                    models.ForeignKey(to="frappe.Document", on_delete=models.CASCADE),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Filiere",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("nom", models.CharField(max_length=64)),
                (
                    "annee",
                    models.ForeignKey(
                        verbose_name="Ann\xe9e",
                        to="frappe.Annee",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Matiere",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("nom", models.CharField(max_length=64)),
                (
                    "filiere",
                    models.ForeignKey(
                        verbose_name="Fili\xe8re",
                        to="frappe.Filiere",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Tag",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("nom", models.CharField(max_length=64)),
                (
                    "color",
                    models.CharField(
                        max_length=7,
                        verbose_name="Couleur",
                        validators=[
                            django.core.validators.RegexValidator(
                                b"^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$",
                                b"Entrez une couleur HTML valide (#XXXXXX)",
                            )
                        ],
                    ),
                ),
                (
                    "ecole",
                    models.ForeignKey(
                        editable=False,
                        to="portailuser.Ecole",
                        verbose_name="\xc9cole",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name="document",
            name="matiere",
            field=models.ForeignKey(
                verbose_name="Mati\xe8re", to="frappe.Matiere", on_delete=models.CASCADE
            ),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name="document",
            name="tags",
            field=models.ManyToManyField(to="frappe.Tag", blank=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name="commentaire",
            name="document",
            field=models.ForeignKey(to="frappe.Document", on_delete=models.CASCADE),
            preserve_default=True,
        ),
    ]
